==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/en/acpacl.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'acl_seg_acp_acl_delete'=>'Access Control: Delete Rule',
'acl_seg_acp_acl_edit'=>'Access Control: Edit Rule',
'acl_seg_acp_acl_list'=>'Access Control: List Rules',
'acl_seg_acp_acl_new'=>'Access Control: Insert Rule',
'acl_seg_acp_cfg_edit'=>'Configuration: Edit Items',
'acl_seg_acp_cfg_list'=>'Configuration: List Items',
'acl_seg_acp_group_delete'=>'User Group: Delete Group',
'acl_seg_acp_group_edit'=>'User Group: Edit Group',
'acl_seg_acp_group_list'=>'User Group: List Groups',
'acl_seg_acp_group_new'=>'User Group: Insert Group',
'acl_seg_acp_log'=>'View Log',
'acl_seg_acp_overview'=>'Executive Overview',
'acl_seg_acp_pp_delete'=>'Post Prefix: Delete Prefix',
'acl_seg_acp_pp_edit'=>'Post Prefix: Edit Prefix',
'acl_seg_acp_pp_list'=>'Post Prefix: List Prefixes',
'acl_seg_acp_pp_new'=>'Post Prefix: Insert Prefix',
'acl_seg_acp_task_edit'=>'Scheduled Task: Edit Task',
'acl_seg_acp_task_list'=>'Scheduled Task: List Tasks',
'acl_seg_acp_user_new'=>'User Account: Insert User',
'acl_seg_cachemgr'=>'Cache Manager',
'acl_seg_forgot_password'=>'Forgot Password',
'acl_seg_help'=>'Help',
'acl_seg_login'=>'Login',
'acl_seg_logout'=>'Logout',
'acl_seg_mcp_overview'=>'Moderation Overview',
'acl_seg_mcp_request'=>'Moderation: Handle Requests',
'acl_seg_member_list'=>'Member List',
'acl_seg_overview'=>'Overview',
'acl_seg_post_approve'=>'Approve/Hide Posting',
'acl_seg_post_delete'=>'Delete Posting',
'acl_seg_post_edit'=>'Edit Posting',
'acl_seg_post_edit_revert'=>'Revert Posting',
'acl_seg_post_lock'=>'Lock/Unlock Posting',
'acl_seg_post_rate'=>'Rate Posting',
'acl_seg_post_reply'=>'Submit Reply Posting',
'acl_seg_post_topic'=>'Submit Topic Posting',
'acl_seg_reauth'=>'Reauthenticate Session',
'acl_seg_register'=>'Register',
'acl_seg_rss'=>'RSS Feed',
'acl_seg_search'=>'Search',
'acl_seg_topic'=>'View Topic',
'acl_seg_ucp_blacklist'=>'User Panel: Blacklisting',
'acl_seg_ucp_bookmark'=>'User Panel: Bookmark',
'acl_seg_ucp_profile'=>'User Panel: My Profile',
'acl_seg_ucp_request'=>'User Panel: Handle Requests'
);
?>

==> larus_board-0.9.16.zip: larus_board-0.9.16/lb_private/lang/en/acpacl.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'acl_seg_acp_acl_delete'=>'Access Control: Delete Rule',
'acl_seg_acp_acl_edit'=>'Access Control: Edit Rule',
'acl_seg_acp_acl_list'=>'Access Control: List Rules',
'acl_seg_acp_acl_new'=>'Access Control: Insert Rule',
'acl_seg_acp_cfg_edit'=>'Configuration: Edit Items',
'acl_seg_acp_cfg_list'=>'Configuration: List Items',
'acl_seg_acp_group_delete'=>'User Group: Delete Group',
'acl_seg_acp_group_edit'=>'User Group: Edit Group',
'acl_seg_acp_group_list'=>'User Group: List Groups',
'acl_seg_acp_group_new'=>'User Group: Insert Group',
'acl_seg_acp_log'=>'View Log',
'acl_seg_acp_overview'=>'Executive Overview',
'acl_seg_acp_pp_delete'=>'Post Prefix: Delete Prefix',
'acl_seg_acp_pp_edit'=>'Post Prefix: Edit Prefix',
'acl_seg_acp_pp_list'=>'Post Prefix: List Prefixes',
'acl_seg_acp_pp_new'=>'Post Prefix: Insert Prefix',
'acl_seg_acp_task_edit'=>'Scheduled Task: Edit Task',
'acl_seg_acp_task_list'=>'Scheduled Task: List Tasks',
'acl_seg_acp_user_delete'=>'User Account: Delete User',
'acl_seg_acp_user_new'=>'User Account: Insert User',
'acl_seg_cachemgr'=>'Cache Manager',
'acl_seg_forgot_password'=>'Forgot Password',
'acl_seg_help'=>'Help',
'acl_seg_login'=>'Login',
'acl_seg_logout'=>'Logout',
'acl_seg_mcp_overview'=>'Moderation Overview',
'acl_seg_mcp_request'=>'Moderation: Handle Requests',
'acl_seg_member_list'=>'Member List',
'acl_seg_overview'=>'Overview',
'acl_seg_post_approve'=>'Approve/Hide Posting',
'acl_seg_post_delete'=>'Delete Posting',
'acl_seg_post_edit'=>'Edit Posting',
'acl_seg_post_edit_revert'=>'Revert Posting',
'acl_seg_post_lock'=>'Lock/Unlock Posting',
'acl_seg_post_rate'=>'Rate Posting',
'acl_seg_post_reply'=>'Submit Reply Posting',
'acl_seg_post_topic'=>'Submit Topic Posting',
'acl_seg_reauth'=>'Reauthenticate Session',
'acl_seg_register'=>'Register',
'acl_seg_rss'=>'RSS Feed',
'acl_seg_search'=>'Search',
'acl_seg_topic'=>'View Topic',
'acl_seg_ucp_blacklist'=>'User Panel: Blacklisting',
'acl_seg_ucp_bookmark'=>'User Panel: Bookmark',
'acl_seg_ucp_profile'=>'User Panel: My Profile',
'acl_seg_ucp_request'=>'User Panel: Handle Requests',
'acl_seg_vcard'=>'Visiting Card'
);
?>
